#!/bin/sh -e
if [ -e /usr/bin/ctrl_bd ]; then
    is7010=`cat /usr/bin/ctrl_bd | grep "XILINX" | wc -l`
else
    is7010=0
fi

if [ $is7010 -eq 1 ];then
    path=$(pwd)

    if [ ! -d /mnt/upgrade ];then
	    mkdir /mnt/upgrade
    fi
    cd ./xilinx

    if [ -f /etc/bitmain-pub.pem ]; then
        if [ ! -f fileinfo.sig ]; then
            echo "RUNME: Cannot Find Signature!!!" >> /tmp/upgrade_result
            exit 1
        fi
        openssl dgst -sha256 -verify /etc/bitmain-pub.pem -signature  fileinfo.sig  fileinfo >/dev/null  2>&1
        vres=$?
        if [ $vres -eq 1 ]; then
            echo "FileList Not Signtured!!!" >> /tmp/upgrade_result
            exit 2
        fi
        sha256sum -s -c fileinfo
        vres=$?
        if [ $vres -eq 1 ]; then
            echo "FileList Check Failed!!!" >> /tmp/upgrade_result
            exit 3
        fi
    fi    
    
    if [ ! -e /dev/ubi_ctrl ];then
            echo "File system isn't UBI, Please update ubi package first!"
            cd $path
            rm -rf *.tar.gz
            exit 1
    fi
    
    if [ -e BOOT.bin ]; then
            flash_erase /dev/mtd0 0x0 0x80 >/dev/null 2>&1
            nandwrite -p -s 0x0 /dev/mtd0 ./BOOT.bin >/dev/null 2>&1
            rm -rf BOOT.bin
    fi

    if [ -e devicetree.dtb ]; then
            flash_erase /dev/mtd0 0x1020000 0x1 >/dev/null 2>&1
            nandwrite -p -s 0x1020000 /dev/mtd0 ./devicetree.dtb >/dev/null 2>&1
            rm devicetree.dtb
    fi

    if [ -e uImage ]; then 
            flash_erase /dev/mtd0 0x1100000 0x40 >/dev/null 2>&1
            nandwrite -p -s 0x1100000 /dev/mtd0 ./uImage >/dev/null 2>&1
            rm uImage
    fi

    if [ -e rootfs.jffs2 ]; then
            if [ -f /dev/mtd3 ];then
            flash_erase /dev/mtd2 0x0 0x1E0 >/dev/null 2>&1
            else
                flash_erase /dev/mtd2 0x0 0x280 >/dev/null 2>&1
            fi
            nandwrite -p -s 0x0 /dev/mtd2 ./rootfs.jffs2 >/dev/null 2>&1
            rm rootfs.jffs2
    fi

    ubiattach /dev/ubi_ctrl -m 2
    mount -t ubifs ubi1:rootfs /mnt/upgrade
    
    cd /mnt/upgrade/upgrade
    rm -rf /mnt/upgrade/upgrade/*
    cd $path

    if [ -e ./xilinx/angstrom_rootfs.jffs2 ];then
        md5=`md5sum ./xilinx/angstrom_rootfs.jffs2 | awk {'print $1'}`
        md5_r=`cat ubi_info`
        if [ $md5 == $md5_r ];then
            cp -rf ./xilinx/angstrom_rootfs.jffs2 /mnt/upgrade/upgrade
            if [ -f /dev/mtd3 ];then
                flash_erase /dev/mtd3 0 0xa0 >/dev/null 2>&1
            fi
        fi
    fi
    flash_erase /dev/mtd0 0x1040000 0x1 >/dev/null 2>&1
    nandwrite -p -s 0x1040000 /dev/mtd0 ./xilinx/upgrade-marker.bin >/dev/null 2>&1

    sync

    umount /mnt/upgrade
    ubidetach -d 1 /dev/ubi_ctrl
    rm -rf *.tar.gz
else
    processornum=`cat /proc/cpuinfo | grep "processor" | wc -l`
    if [ $processornum -ne 1 ];then
	    echo "not 7007 control card" >> /tmp/upgrade_result
		exit 1
	fi
    file=/tmp/$$
	cd ./7007

    if [ -f /etc/bitmain-pub.pem ]; then
	    if [ ! -f fileinfo.sig ]; then
		    echo "RUNME: Cannot Find Signature!!!" >> /tmp/upgrade_result
		    exit 1
	    fi
	    openssl dgst -sha256 -verify /etc/bitmain-pub.pem -signature  fileinfo.sig  fileinfo >/dev/null  2>&1
	    vres=$?
	    if [ $vres -eq 1 ]; then
		    echo "FileList Not Signtured!!!" >> /tmp/upgrade_result
		    exit 2
	    fi	
	    md5sum -s -c fileinfo 
	    vres=$?
	    if [ $vres -eq 1 ]; then
		    echo "FileList Check Failed!!!" >> /tmp/upgrade_result
		    exit 3
	    fi	
    fi

    if [ -e BOOT.bin ]; then
	    flash_erase /dev/mtd0 0x0 0x40 >/dev/null 2>&1
	    nandwrite -p -s 0x0 /dev/mtd0 BOOT.bin >/dev/null 2>&1
    fi

    if [ -e devicetree.dtb ]; then
	    flash_erase /dev/mtd0 0x1A00000 0x1 >/dev/null 2>&1
	    nandwrite -p -s 0x1A00000 /dev/mtd0 devicetree.dtb >/dev/null 2>&1
    fi

    if [ -e uImage ]; then
	    flash_erase /dev/mtd0 0x2000000 0x40 >/dev/null 2>&1
	    nandwrite -p -s 0x2000000 /dev/mtd0 uImage >/dev/null 2>&1
    fi

    if [ -e uramdisk.image.gz ]; then
        md5=`md5sum uramdisk.image.gz | awk {'print $1'}`
        md5_r=`cat md5_info`
        if [ $md5 == $md5_r ];then
	    	flash_erase /dev/mtd1 0x0 0x100 >/dev/null 2>&1
	    	nandwrite -p -s 0x0 /dev/mtd1 uramdisk.image.gz >/dev/null 2>&1
		    if [ -e /dev/mtd4 ]; then
			    flash_erase /dev/mtd4 0x0 0x100 >/dev/null 2>&1
			    nandwrite -p -s 0x0 /dev/mtd4 uramdisk.image.gz >/dev/null 2>&1
		    fi
	    else
		    echo $md5 > /config/md5_error
		    echo $md5_r >> /config/md5_error
		    echo "Error md5! $md5 $md5_r" >> /tmp/upgrade_result
	    fi
    fi

    if [ -e /log ]; then
	    umount -l /log
	    rm -rf /log
	    mkdir /nvdata
	    mount -t jffs2 /dev/mtdblock5 /nvdata
    fi

    rm -rf /config/scanfreqdone 2>/dev/null
    sync >/dev/null 2>&1	
fi
    
